// pages/About.jsx
import React, { useState } from "react";
import { Calendar, Code2, Cpu, Terminal } from "lucide-react";
import { motion } from "framer-motion";
import CodeSnippet from "@/features/shared/components/code/CodeSnippet";
import { siteConfig } from "@/features/shared/components/config/siteConfig";
import SEOHead from "@/features/shared/components/seo/SEOHead";

export default function About() {
  const [isModalOpen, setIsModalOpen] = useState(false);

  // Enhanced structured data for About page
  const aboutStructuredData = [
    {
      "@context": "https://schema.org",
      "@type": "AboutPage",
      "mainEntity": {
        "@type": "Person",
        "name": "Chen Magled",
        "jobTitle": "Tech Lead & Full Stack Engineer",
        "description": "Experienced technology leader with 10+ years in full-stack development, cloud engineering, and AI/ML innovation",
        "knowsAbout": [
          "Full Stack Development",
          "Cloud Engineering",
          "Artificial Intelligence",
          "Machine Learning",
          "Platform Engineering",
          "Team Leadership",
          "System Architecture",
          "DevOps"
        ],
        "hasOccupation": {
          "@type": "Occupation",
          "name": "Tech Lead",
          "occupationLocation": {
            "@type": "City",
            "name": "Tel Aviv"
          },
          "skills": [
            "JavaScript", "TypeScript", "React", "Node.js", "Python",
            "AWS", "Docker", "Kubernetes", "AI/ML", "System Design"
          ]
        }
      }
    }
  ];

  const containerVariants = {
    hidden: { opacity: 0 },
    show: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2,
      },
    },
  };

  const itemVariants = {
    hidden: { opacity: 0, x: -20 },
    show: { opacity: 1, x: 0 },
  };

  const modalVariants = {
    hidden: { opacity: 0 },
    visible: { opacity: 1 },
  };

  // Simple solve function to show in modal
  const solveCode = `function solve(challenge, options = { creative: true, efficient: true }) {
  console.log(\`Solving: \${challenge}\`);
  
  // Analyze the challenge
  const keywords = challenge.toLowerCase().split(" ");
  
  // Determine approach based on options
  const approach = [];
  if (options.creative) approach.push("creative thinking", "innovation");
  if (options.efficient) approach.push("optimization", "performance tuning");
  
  // Generate solution components
  const components = {
    "code": ["refactoring", "clean architecture", "design patterns"],
    "performance": ["caching strategies", "lazy loading", "parallel processing"],
    "ui": ["user-centered design", "accessibility", "responsive layouts"],
    "data": ["efficient algorithms", "optimized queries", "data normalization"],
    "ai": ["ML pipelines", "contextual awareness", "model fine-tuning"]
  };
  
  // Map keywords to solution domains
  const domains = [];
  for (const keyword of keywords) {
    for (const [domain, solutions] of Object.entries(components)) {
      if (keyword.includes(domain)) {
        domains.push(domain);
      }
    }
  }
  
  // Default to code domain if no matches
  if (domains.length === 0) domains.push("code");
  
  // Build the solution
  const solution = {
    approach: approach.join(", "),
    techniques: domains.map(domain => {
      const techniques = components[domain] || components.code;
      return techniques[Math.floor(Math.random() * techniques.length)];
    }),
    isImpactful: true
  };
  
  return solution;
}

// Example usage
const challenge = "slow legacy code with performance issues";
const result = solve(challenge, { creative: true, efficient: true });

console.log(\`Approach: \${result.approach}\`);
console.log(\`Techniques: \${result.techniques.join(", ")}\`);
console.log(\`Is impactful: \${result.isImpactful}\`);`;

  return (
    <>
      <SEOHead
        structuredData={aboutStructuredData}
        keywords={[
          "Chen Magled background",
          "Tech Lead journey",
          "Full Stack Developer experience",
          "Cloud Engineering expertise",
          "AI innovation story",
          "Programming since age 12",
          "Migdal Group Tech Lead",
          "GenAI initiatives leader"
        ]}
      />
      <div className="py-12 sm:py-12">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <motion.div
            variants={containerVariants}
            initial="hidden"
            whileInView="show"
            viewport={{ once: true }}
            className="max-w-3xl mx-auto"
          >
            <motion.div variants={itemVariants} className="text-center mb-10">
              <span className="inline-block px-4 py-2 rounded-full bg-primary/10 text-primary text-sm font-medium">
                Professional Journey
              </span>
              <h1 className="text-3xl sm:text-4xl font-bold mt-4 mb-6">
                From Code Enthusiast to Tech Leader
              </h1>
              <p className="text-lg text-muted-foreground">
                From writing my first line of code at <strong>age 12</strong> to leading <strong>GenAI initiatives</strong> and <strong>full-stack engineering teams</strong> at scale—my journey spans over a decade of building innovative solutions, mentoring developers, and driving digital transformation across diverse industries.
              </p>
            </motion.div>

            {/* Code Snippet with min height */}
            <motion.div variants={itemVariants} className="my-16">
              <div className="min-h-[200px]">
                <CodeSnippet language="javascript">
                  {`// My journey in code
const journey = {
  started: "age 12",
  games: ["MapleStory", "Counter Strike", "Grand Theft Auto: San Andreas - Multiplayer"],
  hobbies: [
    "Coding cool stuff", "Listening to music",
    "Playing video games", "Trying new foods",
    "Traveling to new places", "Working out",
    "Messing with gadgets", "Streaming and content creation"
  ],
  programmingLanguages: ["LUA" ,"PHP" ,"JavaScript", "Python", "TypeScript"],
  focus: [
    "Full Stack Development – from clean UI to robust backend APIs",
    "Cloud Engineering – building scalable, reliable infrastructure",
    "Generative AI – exploring creative and practical AI solutions"
  ],
  passion: [
    "Building things that solve real problems", "Turning ideas into scalable, working products",
    "Writing clean, modern code across the stack", "Exploring how GenAI can be used in meaningful ways",
    "Creating stuff people actually enjoy using"
  ]
};

function buildSomethingAmazing(challenges) {
  const solutions = challenges.map(challenge => 
    solve(challenge, { creative: true, efficient: true }));
  return solutions.filter(solution => solution.isImpactful);
}`}
                </CodeSnippet>
                <div className="mt-6 text-center">
                  <button
                    onClick={() => setIsModalOpen(true)}
                    className="px-4 py-2 bg-primary text-primary-foreground rounded-md hover:bg-primary/90 transition-colors flex items-center gap-2 mx-auto"
                  >
                    <Terminal className="h-4 w-4" aria-hidden="true" />
                    <span>See the solve() function</span>
                  </button>
                </div>
                <div className="mt-6 text-center">
                  <p className="text-lg text-muted-foreground">
                    Now it's your turn to call the buildSomethingAmazing
                    function and watch these challenges turn into solutions!
                  </p>
                </div>
              </div>
            </motion.div>

            {/* Simple Modal for the solve function */}
            {isModalOpen && (
              <div className="fixed inset-0 bg-background/80 backdrop-blur-sm z-50 flex items-center justify-center p-4">
                <motion.div
                  initial="hidden"
                  animate="visible"
                  variants={modalVariants}
                  className="bg-card border border-border w-full max-w-2xl rounded-lg shadow-lg overflow-hidden"
                >
                  <div className="p-4 flex items-center justify-between border-b border-border">
                    <div className="flex items-center gap-2">
                      <Terminal className="h-5 w-5 text-primary" aria-hidden="true" />
                      <h3 className="font-medium">
                        solve() Function Implementation
                      </h3>
                    </div>
                    <button
                      onClick={() => setIsModalOpen(false)}
                      className="h-8 w-8 rounded-full hover:bg-muted flex items-center justify-center"
                      aria-label="Close modal"
                    >
                      <svg
                        width="12"
                        height="12"
                        viewBox="0 0 12 12"
                        fill="none"
                        xmlns="http://www.w3.org/2000/svg"
                      >
                        <path
                          d="M9 3L3 9M3 3L9 9"
                          stroke="currentColor"
                          strokeWidth="1.5"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                        />
                      </svg>
                    </button>
                  </div>
                  <div className="max-h-[70vh] overflow-auto p-1">
                    <CodeSnippet speed={5} language="javascript">{solveCode}</CodeSnippet>
                  </div>
                </motion.div>
              </div>
            )}

            {/* Sections */}
            <div className="space-y-12 mt-12">
              <motion.div
                variants={itemVariants}
                className="flex flex-col sm:flex-row gap-6"
              >
                <div className="flex-shrink-0">
                  <div className="w-12 h-12 rounded-xl bg-blue-100 dark:bg-blue-950/40 flex items-center justify-center shadow-sm dark:shadow-none">
                    <Code2 className="w-6 h-6 text-blue-600 dark:text-blue-400" aria-hidden="true" />
                  </div>
                </div>
                <div>
                  <h3 className="font-semibold mb-2 text-slate-800 dark:text-white">
                    Early Passion for Technology
                  </h3>
                  <p className="text-slate-600 dark:text-gray-300">
                    I began coding at <strong>12 years old</strong> and never looked back. Over the years,
                    I evolved from building basic websites to architecting
                    <strong> advanced AI-powered platforms</strong> and <strong>enterprise-scale full-stack systems</strong>. This early start gave me deep technical foundations and a genuine love for solving complex problems through code.
                  </p>
                </div>
              </motion.div>

              <motion.div
                variants={itemVariants}
                className="flex flex-col sm:flex-row gap-6"
              >
                <div className="flex-shrink-0">
                  <div className="w-12 h-12 rounded-xl bg-purple-100 dark:bg-purple-950/40 flex items-center justify-center shadow-sm dark:shadow-none">
                    <Calendar className="w-6 h-6 text-purple-600 dark:text-purple-400" aria-hidden="true" />
                  </div>
                </div>
                <div>
                  <h3 className="font-semibold mb-2 text-slate-800 dark:text-white">Leadership & Impact</h3>
                  <p className="text-slate-600 dark:text-gray-300">
                    Currently <strong>Tech Lead at Migdal Group</strong>, driving <strong>GenAI adoption</strong>
                    and <strong>cloud platform transformation</strong> for 15+ engineers. Previously led full-stack
                    and AI initiatives at <strong>LivePerson</strong> and <strong>Menora Mivtachim</strong>, with a focus on
                    scalability, developer velocity, and measurable product impact across diverse business domains.
                  </p>
                </div>
              </motion.div>

              <motion.div
                variants={itemVariants}
                className="flex flex-col sm:flex-row gap-6"
              >
                <div className="flex-shrink-0">
                  <div className="w-12 h-12 rounded-xl bg-green-100 dark:bg-green-950/40 flex items-center justify-center shadow-sm dark:shadow-none">
                    <Cpu className="w-6 h-6 text-green-600 dark:text-green-400" aria-hidden="true" />
                  </div>
                </div>
                <div>
                  <h3 className="font-semibold mb-2 text-slate-800 dark:text-white">Innovation & Future Focus</h3>
                  <p className="text-slate-600 dark:text-gray-300">
                    Deeply invested in <strong>Generative AI</strong> and <strong>cloud-native architectures</strong>.
                    I thrive on turning cutting-edge technologies into practical tools that solve real business problems,
                    from <strong>AI-powered call center solutions</strong> to <strong>developer productivity platforms</strong>
                    that accelerate engineering teams and improve code quality at scale.
                  </p>
                </div>
              </motion.div>
            </div>

            {/* Education & Background Section - Enhanced for SEO */}
            <motion.div variants={itemVariants} className="mt-16">
              <h2 className="text-2xl font-bold mb-8">
                Education & Professional Development
              </h2>
              <div className="space-y-8">
                {siteConfig.education?.map((edu, index) => (
                  <div
                    key={index}
                    className="bg-card border border-card-border rounded-xl p-6 shadow-md transition-all hover:shadow-lg"
                  >
                    <div className="flex items-center gap-4 mb-3">
                      <div className="w-10 h-10 rounded-lg bg-primary/10 flex items-center justify-center">
                        <svg
                          xmlns="http://www.w3.org/2000/svg"
                          width="20"
                          height="20"
                          viewBox="0 0 24 24"
                          fill="none"
                          stroke="currentColor"
                          strokeWidth="2"
                          strokeLinecap="round"
                          strokeLinejoin="round"
                          className="text-primary"
                        >
                          <path d="M22 10v6M2 10l10-5 10 5-10 5z"></path>
                          <path d="M6 12v5c3 3 9 3 12 0v-5"></path>
                        </svg>
                      </div>
                      <div>
                        <h3 className="font-semibold text-lg">
                          {edu.institution} – {edu.degree}
                        </h3>
                        <p className="text-muted-foreground text-sm">
                          {edu.period}
                        </p>
                      </div>
                    </div>
                    <div className="ml-14">
                      <p className="text-muted-foreground">{edu.description}</p>
                    </div>
                  </div>
                ))}
              </div>
            </motion.div>
          </motion.div>
        </div>
      </div>
    </>
  );
}
